==> jackrabbit-oak-1.4.26-src.zip: jackrabbit-oak-1.4.26/oak-core/src/main/java/org/apache/jackrabbit/oak/plugins/observation/filter/FilterConfigMBean.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.jackrabbit.oak.plugins.observation.filter;

public interface FilterConfigMBean {
    String TYPE = "FilterConfig";

    /**
     * A set of paths whose subtrees include all events of this filter.
     * @return  list of paths
     * @see org.apache.jackrabbit.oak.plugins.observation.filter.FilterBuilder#addSubTree(String)
     */
    String[] getSubTrees();

    /**
     * Whether to include cluster local changes.
     *
     * @return true if cluster local changes need to be included
     */
    boolean isIncludeClusterLocal();

    /**
     * Whether to include cluster external changes.
     *
     * @return true if cluster external changes need to be included
     */
    boolean isIncludeClusterExternal();
}

==> jackrabbit-oak-1.22.23-src.zip: jackrabbit-oak-1.22.23/oak-core/src/main/java/org/apache/jackrabbit/oak/plugins/observation/filter/FilterConfigMBean.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.jackrabbit.oak.plugins.observation.filter;

public interface FilterConfigMBean {
    String TYPE = "FilterConfig";

    /**
     * A set of paths, potentially containing globs, that include all events of this filter.
     * @return  list of paths
     * @see org.apache.jackrabbit.oak.plugins.observation.filter.FilterBuilder#addSubTree(String)
     */
    String[] getPaths();

    /**
     * Whether to include cluster local changes.
     *
     * @return true if cluster local changes need to be included
     */
    boolean isIncludeClusterLocal();

    /**
     * Whether to include cluster external changes.
     *
     * @return true if cluster external changes need to be included
     */
    boolean isIncludeClusterExternal();
}
